@@ -129,6 +129,13 @@ class OOSheet(OODoc):
         """
 
         if not selector:
+            address = self.model.CurrentSelection.RangeAddress
+            self.sheet = self.model.Sheets.getByIndex(address.Sheet)
+            self.start_col = address.StartColumn
+            self.end_col = address.EndColumn
+            self.start_row = address.StartRow
+            self.end_row = address.EndRow
+            
             return
         
         try:
@@ -308,9 +315,12 @@ class OOSheet(OODoc):
 
         date_format = uno.getConstantByName( "com.sun.star.util.NumberFormat.DATE" )
         formats = self.model.getNumberFormats()
-        locale = uno.createUnoStruct( "com.sun.star.lang.Locale" )
         cells = self.sheet.getCellRangeByName(self.selector)
-        cells.NumberFormat = formats.getStandardFormat( date_format, locale )
+        #if formats.getByKey(cells).Type != date_format:
+        for cell in self.cells:
+            if formats.getByKey(cell.NumberFormat).Type != date_format:
+                locale = uno.createUnoStruct( "com.sun.star.lang.Locale" )
+                cell.NumberFormat = formats.getStandardFormat( date_format, locale )
 
 
     def set_date(self, date):
@@ -811,14 +821,3 @@ def print_help():
     print "Usage: %s document.ods script.py" % script_name
     sys.exit(1)
 
-    
-
-
-        
-        
-
-        
-        
-
-
-
